<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Español [ES]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=169
Author: Piwigo team
Author URI: http://piwigo.org
*/

// Langage informations
$lang_info['language_name'] = 'Español';
$lang_info['country'] = 'España';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'es';
$lang_info['zero_plural'] = false;

$lang['%d Kb'] = '%d Ko';
$lang['%d album updated'] = '%d àlbum actualizado';
$lang['%d albums updated'] = '%d àlbumes actualizados';
$lang['%d comment to validate'] = '%d Comentario usuario que hay que validar';
$lang['%d comments to validate'] = '%d comentarios de usuario que hay que validar';
$lang['%d new comment'] = '%d Nuevo comentario usuario';
$lang['%d new comments'] = '%d nuevos comentarios del usuario';
$lang['%d comment'] = '%d Comentario';
$lang['%d comments'] = '%d Comentarios';
$lang['%d hit'] = '%d visitas';
$lang['%d hits'] = '%d visitas';
$lang['%d new photo'] = '%d nueva fotos';
$lang['%d new photos'] = '%d nuevas fotos';
$lang['%d new user'] = '%d nuevo usuario';
$lang['%d new users'] = '%d nuevos usuarios';
$lang['About'] = 'Acerca de';
$lang['All tags'] = 'Todas las etiquetas';
$lang['Any tag'] = 'Cualquier etiqueta';
$lang['At least one listed rule must be satisfied.'] = 'Debe elegir al menos una de las reglas que se listan.';
$lang['At least one tag must match'] = 'Debe coincidir al menos una de las etiquetas';
$lang['Author'] = 'Autor';
$lang['Albums'] = 'Albums';
$lang['Album'] = 'Álbum';
$lang['Close this window'] = 'Cerrar la ventana';
$lang['Complete RSS feed (photos, comments)'] = 'Flujo RSS completo (fotos, comentarios)';
$lang['Confirm Password'] = 'Confirmar la contraseña';
$lang['Connection settings'] = 'Datos de conexión';
$lang['Login'] = 'Identificarse';
$lang['Contact webmaster'] = 'Contactar el webmastre';
$lang['Create a new account'] = 'Crear una nueva cuenta';
$lang['Created on'] = 'Creada el';
$lang['Creation date'] = 'Fecha de creación';
$lang['Current password is wrong'] = 'La contraseña actual es incorrecta';
$lang['Dimensions'] = 'Dimensiones';
$lang['Display'] = 'Monstrar';
$lang['Each listed rule must be satisfied.'] = 'Debe cumplimentar cada una de las reglas';
$lang['Email address is missing. Please specify an email address.'] = 'Falta su dirección electrónica';
$lang['Email address'] = 'Dirección electrónica';
$lang['Enter your personnal informations'] = 'Cumplimente sus datos personales';
$lang['Error sending email'] = 'Error de envío';
$lang['File name'] = 'Nombre del archivo';
$lang['File'] = 'Fichero';
$lang['Filesize'] = 'Tamaño';
$lang['Filter and display'] = 'Filtrar y mostrar';
$lang['Filter'] = 'Filtro';
$lang['Forgot your password?'] = '¿Olvidó su contraseña?';
$lang['Go through the gallery as a visitor'] = 'Recorrer la galería como visitante';
$lang['Help'] = 'Ayuda';
$lang['Identification'] = 'Identificación';
$lang['Photos only RSS feed'] = 'Flujo RSS sólo las fotos';
$lang['Keyword'] = 'Palabra clave';
$lang['Links'] = 'Enlaces';
$lang['N/A'] = 'no disponible';
$lang['New on %s'] = 'Nuevo el %s';
$lang['New password confirmation does not correspond'] = 'Los valores de la contraseña no coinciden';
$lang['Notification'] = 'Notificación RSS';
$lang['Number of items'] = 'Número de artículos';
$lang['Original dimensions'] = 'Dimensiones originales';
$lang['Password forgotten'] = 'Contraseña olvidada';
$lang['Password'] = 'Contraseña';
$lang['Post date'] = 'Añadido el día';
$lang['Posted on'] = 'Añadido el';
$lang['Profile'] = 'Perfil';
$lang['Quick connect'] = 'Conexión rápida';
$lang['RSS feed'] = 'flujo RSS';
$lang['Register'] = 'Regístrarse';
$lang['Registration'] = 'Registro';
$lang['Related tags'] = 'Etiquetas relacionadas';
$lang['Reset'] = 'Cancelar';
$lang['Retrieve password'] = 'Recuperar la contraseña';
$lang['Search rules'] = 'Criterios de búsqueda';
$lang['Search tags'] = 'Buscar etiquetas';
$lang['Search'] = 'Búsqueda';
$lang['display available tags'] = 'Ver las etiquetas disponibles';
$lang['Since'] = 'Desde';
$lang['Sort by'] = 'Clasificar según';
$lang['Sort order'] = 'Orden de Clasificación';
$lang['Tag'] = 'Etiqueta';
$lang['Tags'] = 'Etiquetas';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'El flujo RSS notifica eventos de la galería:fotos nuevas, categorías actualizadas, nuevos comentarios de usuarios. Debe usarse con un lector de flujos RSS.';
$lang['Unknown feed identifier'] = 'Identificador de RSS desconocido';
$lang['User comments'] = 'Comentarios del usuario';
$lang['Username'] = 'Nombre del usuario';
$lang['Visits'] = 'Visitas';
$lang['Webmaster'] = 'Webmastre';
$lang['Week %d'] = 'Semana %d';
$lang['About Piwigo'] = 'Acerca de Piwigo';
$lang['You are not authorized to access the requested page'] = 'No dispone de autorización para ver la página solicitada';
$lang['add to caddie'] = 'Agregar a la cesta';
$lang['add this photo to your favorites'] = 'agregar esta foto a sus favoritos';
$lang['Administration'] = 'Administración';
$lang['all'] = 'todo';
$lang['ascending'] = 'ascendiente';
$lang['author(s) : %s'] = 'autor(es) : %s';
$lang['Expand all albums'] = 'Ver todos los àlbumes';
$lang['posted after %s (%s)'] = 'disponible con posterioridad al %s (%s)';
$lang['posted before %s (%s)'] = 'disponible antes del %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'disponible entre él %s (%s) y el %s (%s)';
$lang['posted on %s'] = 'disponible el %s';
$lang['Best rated'] = 'Mejor valoracion';
$lang['display best rated photos'] = 'mostrar las fotos con mejor calificación';
$lang['caddie'] = 'Carrito';
$lang['Calendar'] = 'Calendario';
$lang['All'] = 'Todo';
$lang['display each day with photos, month per month'] = 'Visualizacíon año por año,  mes por mes, día por dia,';
$lang['View'] = 'Vista';
$lang['chronology_monthly_calendar'] = 'Calendario mensual';
$lang['chronology_monthly_list'] = 'Lista mensual';
$lang['chronology_weekly_list'] = 'Lista semanal';
$lang['Click here if your browser does not automatically forward you'] = 'Pulse aquí si su navegador no le reenvía a la página solicitada.';
$lang['comment date'] = 'Fecha de comentario';
$lang['Comment'] = 'Comentario';
$lang['Your comment has been registered'] = 'Su comentario ha sido añadido';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Systema anti-abuso : por favor, aguarde unos momentos antes de agregar un nuevo comentario';
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = 'Su comentario no ha sido registrado porque no ha superado las reglas de validación';
$lang['An administrator must authorize your comment before it is visible.'] = 'El administrador debe validar su comentario antes de que sea visible.';
$lang['This login is already used by another user'] = 'Este nombre de usuario ya ha sido registrado con anterioridad, por favor inténtelo con otro';
$lang['Comments'] = 'Comentarios';
$lang['Add a comment'] = 'Agregar comentario';
$lang['created after %s (%s)'] = 'Creado después del %s (%s)';
$lang['created before %s (%s)'] = 'creado antes del %s (%s)';
$lang['created between %s (%s) and %s (%s)'] = 'creado entre el %s (%s) y el %s (%s)';
$lang['created on %s'] = 'creado el %s';
$lang['Customize'] = 'Personalizar';
$lang['Your Gallery Customization'] = 'Personalización de su pantalla ';
$lang['day'][0] = 'Domingo';
$lang['day'][1] = 'Lunes';
$lang['day'][2] = 'Martes';
$lang['day'][3] = 'Miércoles';
$lang['day'][4] = 'Jueves';
$lang['day'][5] = 'Viernes';
$lang['day'][6] = 'Sábado';
$lang['Default'] = 'Por defecto';
$lang['delete this photo from your favorites'] = 'Borrar esta foto de sus favoritos';
$lang['Delete'] = 'Suprimir';
$lang['descending'] = 'descendente';
$lang['download'] = 'descargar';
$lang['download this file'] = 'descargar este fichero';
$lang['edit'] = 'Editar';
$lang['wrong date'] = 'Fecha errónea';
$lang['excluded'] = 'Excluidos';
$lang['Your favorites'] = 'Mis favoritos';
$lang['display your favorites photos'] = 'mostrar mis fotos favoritas';
$lang['Favorites'] = 'Favoritas';
$lang['First'] = 'Primera página';
$lang['The gallery is locked for maintenance. Please, come back later.'] = 'Se están realizando operaciones de mantenimiento, regrese más tarde.';
$lang['Page generated in'] = 'Página generada en';
$lang['guest'] = 'Visitante';
$lang['Hello'] = 'Hola';
$lang['available for administrators only'] = 'disponible sólo para los administradores';
$lang['display this album'] = 'muestra las fotos en el directorio raíz de este àlbum';
$lang['display last user comments'] = 'Ver los últimos comentarios de los usuarios';
$lang['customize the appareance of the gallery'] = 'personalizar el aspecto de la galería';
$lang['search'] = 'Buscar';
$lang['Home'] = 'Inicio';
$lang['in this album'] = 'en este àlbum';
$lang['in %d sub-album'] = 'en este %d sub-àlbum';
$lang['in %d sub-albums'] = 'en estos %d sub-àlbumes';
$lang['included'] = 'incluidos';
$lang['Invalid password!'] = 'Contraseña incorrecta !';
$lang['Language'] = 'Idioma';
$lang['last %d days'] = '%d últimos días';
$lang['Last'] = 'Última página';
$lang['Logout'] = 'Desconexión';
$lang['E-mail address'] = $lang['Email address'];
$lang['obligatory'] = 'obligatorio';
$lang['Maximum photo height'] = 'Altura máxima de las fotos';
$lang['Maximum height must be a number superior to 50'] = 'La altura de las fotos debe ser superior a 50';
$lang['Maximum photo width'] = 'Ancho máximo de las fotos';
$lang['Maximum width must be a number superior to 50'] = 'El ancho de las fotos debe ser superior a 50';
$lang['display a calendar by creation date'] = 'mostrar las imágenes en un calendario, por fecha de subida';
$lang['display all photos in all sub-albums'] = 'Ver todas las fotos de los abumes y sub-albumes';
$lang['return to normal view mode'] = 'Volver a la vista normal';
$lang['display a calendar by posted date'] = 'Mostrar las imágenes en un calendario por fecha de agregación';
$lang['month'][10] = 'Octubre';
$lang['month'][11] = 'Noviembre';
$lang['month'][12] = 'Diciembre';
$lang['month'][1] = 'Enero';
$lang['month'][2] = 'Febrero';
$lang['month'][3] = 'Marzo';
$lang['month'][4] = 'Abril';
$lang['month'][5] = 'Mayo';
$lang['month'][6] = 'Junio';
$lang['month'][7] = 'Julio';
$lang['month'][8] = 'Agosto';
$lang['month'][9] = 'Septiembre';
$lang['Most visited'] = 'Imágenes más vistas';
$lang['display most visited photos'] = 'mostrar las fotos más vistas';
$lang['The number of photos per page must be a not null scalar'] = 'La cantidad de fotos por pagina debe ser un número entero superior a cero';
$lang['Number of photos per page'] = 'Número de miniaturas por pagina';
$lang['Unknown identifier'] = 'Identificador desconocido';
$lang['New password'] = 'Nueva contraseña';
$lang['Rate this photo'] = 'Votar esta foto';
$lang['Next'] = 'Página siguiente';
$lang['no rate'] = 'no valorada';
$lang['Photos posted within the last %d day.'] = 'Sólo muestra los fotos incorporadas desde el %d día.';
$lang['Photos posted within the last %d days.'] = 'Sólo muestra las imágenes incorporadas desde los últimos %d dias.';
$lang['password updated'] = 'contraseña actualizada';
$lang['Recent period must be a positive integer value'] = 'El período debe ser un número entero positivo';
$lang['photo'] = 'Foto';
$lang['Click on the photo to see it in high definition'] = 'Haga clic en la foto para verla en alta resolución';
$lang['Show file metadata'] = 'Mostrar los meta-datos del fichero';
$lang['Powered by'] = 'Distribuido por';
$lang['Preferences'] = 'Preferencias';
$lang['Previous'] = 'Página anterior';
$lang['Random photos'] = 'foto al azar';
$lang['display a set of random photos'] = 'mostrar un conjunto aleatorio de fotos';
$lang['Recent albums'] = 'Álbumes recientes';
$lang['display recently updated albums'] = 'Ver los àlbumes recien creados o actualizados';
$lang['Recent period'] = 'Número de imágenes recientes';
$lang['Recent photos'] = 'fotos recientes';
$lang['display most recent photos'] = 'mostrar las fotos más recientes';
$lang['Redirection...'] = 'Redirección...';
$lang['Please, enter a login'] = 'Por favor, indique un nombre de usuario';
$lang['login mustn\'t end with a space character'] = 'el nombre de usuario no debe terminar por un espacio';
$lang['login mustn\'t start with a space character'] = 'el nombre de usuario no debe empezar por un espacio';
$lang['this login is already used'] = 'Este nombre de usuario ya ha sido escogido con anterioridad';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'El formato de la dirección e-mail debe ser xxx@yyy.eee (ejemplo: jack@altern.org)';
$lang['please enter your password again'] = 'Por favor, escriba de nuevo su contraseña';
$lang['Auto login'] = 'Conexión automática';
$lang['remove this tag from the list'] = 'quitar este tag de la lista';
$lang['representative'] = 'representante';
$lang['Search for Author'] = 'Buscar por autor';
$lang['Search in albums'] = 'Buscar en los àlbumes';
$lang['Search by Date'] = 'Buscar por fecha';
$lang['Date'] = 'del dia';
$lang['End-Date'] = 'Hasta el dia';
$lang['Kind of date'] = 'Tipo de fecha';
$lang['Search for words'] = 'Buscar por palabra';
$lang['Search for all terms'] = 'Buscar todas las palabras';
$lang['Search for any terms'] = 'Buscar una de las palabras';
$lang['Empty query. No criteria has been entered.'] = 'Demanda vacía. Ningún criterio surtido..';
$lang['Search Options'] = 'Opciones de búsqueda';
$lang['Search results'] = 'Resultados de la búsqueda';
$lang['Search in sub-albums'] = 'Buscar en los sub-àlbumes';
$lang['searched words : %s'] = 'Palabras de búsqueda : %s';
$lang['Contact'] = 'Contactar';
$lang['set as album representative'] = 'Elegir como cabeza de este àlbum';
$lang['Show number of comments'] = 'Mostrar el número de comentarios';
$lang['Show number of hits'] = 'Mostrar el número de visualizaciones';
$lang['slideshow'] = 'Diaporama';
$lang['stop the slideshow'] = 'Detener el diaporama';
$lang['Specials'] = 'Herramientas';
$lang['SQL queries in'] = 'búsquedas SQL en';
$lang['display only recently posted photos'] = 'Seleccionar sólo los fotos incorporados recientemente';
$lang['return to the display of all photos'] = 'Volver a mostrar todos los fotos';
$lang['the beginning'] = 'el principio';
$lang['Interface theme'] = 'Tema';
$lang['Thumbnails'] = 'Miniaturas';
$lang['Menu'] = 'Menú';
$lang['A comment on your site'] = 'Una opinión sobre esta pagina';
$lang['today'] = 'hoy';
$lang['Update your rating'] = 'Actualizar la valoración';
$lang['wrong filename'] = 'Nombre de directorio incorrecto';
$lang['the username must be given'] = 'Indique el nombre de usuario';
$lang['useful when password forgotten'] = 'Útil en caso de que olvideis la contraseña';
$lang['Quick search'] = 'Búsqueda rápida';
$lang['Connected user: %s'] = 'Usuario conectado: %s';
$lang['IP: %s'] = 'IP: %s';
$lang['Browser: %s'] = 'Navegador: %s';
$lang['Author: %s'] = 'Autor: %s';
$lang['Comment: %s'] = 'Comentario: %s';
$lang['Comment by %s'] = 'Comentario de %s';
$lang['User: %s'] = 'Usuario: %s';
$lang['Email: %s'] = 'Email: %s';
$lang['Admin: %s'] = 'Administración: %s';
$lang['Registration of %s'] = 'Registro de %s';
$lang['Album: %s'] = 'Álbum : %s';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'El estatus del usuario "guest" no es conforme, se utilizará el estatus por defecto. Por favor, informe al administrador del sitio.';
$lang['this email address is already in use'] = 'Otro usuario ya utiliza esta dirección e-mail';
$lang['Album results for'] = 'Résultados de los  àlbumes por';
$lang['Tag results for'] = 'Resultados de las etiquetas para';
$lang['from %s to %s'] = 'de %s a %s';
$lang['Play of slideshow'] = 'Lectura del diaporama';
$lang['Pause of slideshow'] = 'Pausa del diaporama';
$lang['Repeat the slideshow'] = 'Repetir el diaporama';
$lang['Not repeat the slideshow'] = 'No repetir el diaporama ';
$lang['Reduce diaporama speed'] = 'Disminuir la velocidad del diaporama';
$lang['Accelerate diaporama speed'] = 'Acelerar la velocidad del diaporama';
$lang['Submit'] = 'Validar';
$lang['Yes'] = 'Si';
$lang['No'] = 'No';
$lang['%d photo'] = '%d Foto';
$lang['%d photos'] = '%d Fotos';
$lang['%d photo is also linked to current tags'] = '%d foto también está relacionada con los tags actuales';
$lang['%d photos are also linked to current tags'] = '%d fotos también están relacionada con los tags actuales';
$lang['display photos linked to this tag'] = 'Ver únicamente las fotos relacionadas a ese tag';
$lang['photos posted during the last %d days'] = 'fotos agregadas los últimos %d días';
$lang['Piwigo Help'] = 'Ayuda de Piwigo';
$lang['Rank'] = 'Fila';
$lang['group by letters'] = 'Reagrupar por letras';
$lang['letters'] = 'letras';
$lang['show tag cloud'] = 'mostrar la nube de tags';
$lang['cloud'] = 'nube';
$lang['Reset to default values'] = 'Restablecer los valores predeterminados';
$lang['Sent by'] = 'Enviado por';
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'El cookies están bloqueados o sostenidos por su navegador Web. Usted debe acelerar el cookies para conectarse.';
$lang['delete all photos from your favorites'] = 'borrar todas las fotos de tus favoritos';
$lang['Are you sure?'] = '¿Seguro?';
$lang['delete this comment'] = 'Borrar este comentario';
$lang['edit this comment'] = 'editar este comentario';
$lang['Edit a comment'] = 'Editar un comentario';
$lang['(!) This comment requires validation'] = '(!) Este comentario debe ser validado';
$lang['Welcome'] = 'Bienvenida';
$lang['Welcome to your Piwigo photo gallery!'] = 'Bienvenidos a su galería foto Piwigo!';
$lang['... or browse your empty gallery'] = '... o navegue por su galería vacía';
$lang['... or please deactivate this message, I will find my way by myself'] = '... o desactive este mensaje, yo mismo me desenredaré';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = '¡Buenos días %s, su galería foto Piwigo está vacía!';
$lang['I want to add photos'] = 'Quiero subir fotos';
$lang['Manage this user comment: %s'] = 'Administrar este comentario: %s';
$lang['This author modified following comment:'] = 'Este autor modificó el comentario siguiente:';
$lang['This author removed the comment with id %d'] = 'Este autor suprimió el comentario sustentador al que él identificaba %d';
$lang['validate this comment'] = 'Validar este comentario';
$lang['html tags are not allowed in login'] = 'Etiquetas HTML no están permitidas en el area de conección';
$lang['%d rates'] = '%d Notas';
$lang['Rating score'] = 'Puntuación';
$lang['Enter a username or email address'] = 'Introduzca su nombre de usuario o dirección de correo electrónico';
$lang['Invalid username or email'] = 'Nombre de usuario o dirección de correo electrónico no válida';
$lang['Password reset is not allowed for this user'] = 'La renovación de la contraseña no se permite para este usuario';
$lang['User "%s" has no email address, password reset is not possible'] = 'El usuario "% s" \'s no tiene dirección de correo electrónico, la renovación de la contraseña no es posible';
$lang['Someone requested that the password be reset for the following user account:'] = 'Alguien ha solicitado la renovación de su contraseña para el siguiente usuario :';
$lang['Username "%s" on gallery %s'] = 'El usuario "%s" en la galería %s';
$lang['To reset your password, visit the following address:'] = 'Para renovar su contraseña, haga clic en el siguiente enlace :';
$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Si se trata de un error, ignorar este mensaje y la solicitud no será tomada en cuenta.';
$lang['Password Reset'] = 'Renovar su contraseña';
$lang['Check your email for the confirmation link'] = 'Revise su correo electrónico para encontrar el enlace de confirmación';
$lang['Invalid key'] = 'clave no válida';
$lang['The passwords do not match'] = 'Las contraseñas no coinciden';
$lang['Your password has been reset'] = 'Su contraseña se ha restablecida';
$lang['Return to home page'] = 'Volver a la página de inicio';
$lang['Please enter your username or email address.'] = 'Gracias por introducir su nombre de usuario o dirección de correo electrónico.';
$lang['You will receive a link to create a new password via email.'] = 'Recibira por email un enlace para renovar su contraseña.';
$lang['Username or email'] = 'Nombre de usuario o dirección de correo electrónico';
$lang['Change my password'] = 'Cambiar mi contraseña';
$lang['Enter your new password below.'] = 'Ingrese su nueva contraseña abajo.';
$lang['Reset Password'] = 'Restablecer la contraseña';
$lang['EXIF Metadata'] = 'Datos EXIF';
$lang['IPTC Metadata'] = 'Datos IPTC';

?>